@@ -135,6 +135,12 @@ class System(base.ResourceBase):
     """Indicates if a given resource has a maintenance window assignment
     for applying settings or operations"""
 
+    _settings = settings.SettingsField()
+    """Settings Resource is used to represent the future intended state
+    of a Resource
+    Ref: http://redfish.dmtf.org/schemas/DSP0266_1.7.0.html#settings-resource
+    """
+
     _actions = ActionsField('Actions', required=True)
 
     def __init__(self, connector, identity, redfish_version=None,
@@ -239,6 +245,26 @@ class System(base.ResourceBase):
                     valid_values=valid_targets)
 
             fishy_target = sys_maps.BOOT_SOURCE_TARGET_MAP_REV[target]
+            # NOTE(janders) on SuperMicro X11 and X12 machines, virtual media
+            # is presented as an "USB CD" drive as opposed to a CD drive. Both
+            # are present in the list of boot devices, however only selecting
+            # UsbCd as the boot source results in a successful boot from
+            # vMedia. If "CD" is selected, boot fails even if vMedia is
+            # inserted. This code detects a case where a SuperMicro machine is
+            # about to attempt boot from CD and overrides the boot device to
+            # UsbCd instead which makes boot from vMedia work as expected.
+            if (self.manufacturer and self.manufacturer.lower() == 'supermicro'
+                    and fishy_target == sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
+                        sys_cons.BOOT_SOURCE_TARGET_CD]
+                    and sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
+                        sys_cons.BOOT_SOURCE_TARGET_USB_CD]
+                    in self.boot.allowed_values):
+                fishy_target = sys_maps.BOOT_SOURCE_TARGET_MAP_REV[
+                    sys_cons.BOOT_SOURCE_TARGET_USB_CD]
+                LOG.debug('Boot from vMedia was requested on a SuperMicro'
+                          'machine. Overriding boot device from %s to %s.',
+                          sys_cons.BOOT_SOURCE_TARGET_CD,
+                          fishy_target)
 
             data['Boot']['BootSourceOverrideTarget'] = fishy_target
 
@@ -262,9 +288,23 @@ class System(base.ResourceBase):
 
             data['Boot']['BootSourceOverrideMode'] = fishy_mode
 
+        headers = None
+        etag = self._get_etag()
+        path = self.path
+
+        # NOTE(janders): checking if @Redfish.Settings are available; if so
+        # using the URI from the SettingsObject. Also ensuring the ETag URI
+        # matches in this case (the one above would not be valid for new URI).
+        if self._settings and self._settings.resource_uri:
+            path = self._settings.resource_uri
+            resp = self._conn.get(path)
+            etag = resp.headers.get('ETag')
+
         # TODO(lucasagomes): Check the return code and response body ?
         #                    Probably we should call refresh() as well.
-        self._conn.patch(self.path, data=data)
+        if etag is not None:
+            headers = {'If-Match': etag}
+        self._conn.patch(path, data=data, headers=headers)
 
     # TODO(etingof): we should remove this method, eventually
     def set_system_boot_source(
